@@ -19,22 +19,29 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-
 """ 
-for properties:
->>> import notion.properties as prop
+### Properties:
+>>> from notion import properties as prop
 
-for queries:
->>> import notion.query as query
+### Queries:
+>>> from notion import query
+query objects:
+ - SortFilter
+ - PropertyFilter
+ - CompoundFilter
+ - TimestampFilter
+ - EntryTimestampSort
+ - PropertyValueSort
+
+To combine a CompoundFilter/PropertyFilter with a SortFilter, use `notion.build_payload(...)`
 """
-
 from typing import Sequence
 
-from notion.api import Block, BlockFactory, Database, Page, Workspace
-from notion.properties.build import build_payload
-
 import notion.properties as properties
 import notion.query as query
+from notion.api import Block, BlockFactory, Database, Page, Workspace
+from notion.api._pkgv import inspect_pkg_version
+from notion.properties.build import build_payload
 
 __all__: Sequence[str] = (
     "Page",
@@ -45,4 +52,5 @@ __all__: Sequence[str] = (
     "build_payload",
     "properties",
     "query",
+    "inspect_pkg_version",
 )
