@@ -34,12 +34,12 @@ try:
 except ModuleNotFoundError:
     import json
 
-    default_json: ModuleType = json  # type: ignore[no-redef]
+    default_json: ModuleType = json
 
 import requests
 
 from notion.api._about import *
-from notion.exceptions import *
+from notion.exceptions import NotionUnauthorized, validate_response
 
 __all__: Sequence[str] = ["_NotionClient"]
 
@@ -62,9 +62,10 @@ class _NotionClient:
             except KeyError:
                 if not token:
                     raise NotionUnauthorized(
-                        "{}{}".format(
-                            f"notion.{self.__class__.__name__}: Missing Token, ",
-                            "Check .env config | if token is named `NOTION_TOKEN`",
+                        "%s. %s."
+                        % (
+                            f"notion.{self.__class__.__name__}: Missing Token",
+                            "Check if `NOTION_TOKEN` is set in environment variables",
                         )
                     )
 
@@ -77,7 +78,7 @@ class _NotionClient:
             "Notion-Version": __notion_version__,
         }
 
-        if notion_version is not None:
+        if notion_version:
             self.headers["Notion-Version"] = notion_version
 
     @staticmethod
@@ -89,26 +90,24 @@ class _NotionClient:
         page_size: Optional[int] = None,
         start_cursor: Optional[str] = None,
     ) -> str:
-        object_id_ = f"/{object_id}" if object_id else ""
-        children_ = "/children" if children else ""
-        page_size_ = f"&page_size={page_size}" if page_size else ""
-        start_cursor_ = f"&start_cursor={start_cursor}" if start_cursor else ""
-        urlparam_ = ""
-        if any([page_size, start_cursor]):
-            urlparam_ = "?"
-
-        return "{}blocks{}{}{}{}{}".format(
-            __base_url__, object_id_, children_, urlparam_, start_cursor_, page_size_
+        return "%sblocks%s%s%s%s%s" % (
+            __base_url__,
+            f"/{object_id}" if object_id else "",
+            "/children" if children else "",
+            "?" if any([page_size, start_cursor]) else "",
+            f"&start_cursor={start_cursor}" if start_cursor else "",
+            f"&page_size={page_size}" if page_size else "",
         )
 
     @staticmethod
     def _database_endpoint(
         object_id: Optional[str] = None, /, *, query: Optional[bool] = False
     ) -> str:
-        object_id_ = f"/{object_id}" if object_id else ""
-        query_ = "/query" if query else ""
-
-        return f"{__base_url__}databases{object_id_}{query_}"
+        return "%sdatabases%s%s" % (
+            __base_url__,
+            f"/{object_id}" if object_id else "",
+            "/query" if query else "",
+        )
 
     @staticmethod
     def _pages_endpoint(
@@ -118,11 +117,12 @@ class _NotionClient:
         properties: Optional[bool] = False,
         property_id: Optional[str] = None,
     ) -> str:
-        object_id_ = f"/{object_id}" if object_id else ""
-        properties_ = "/properties" if properties else ""
-        property_id_ = f"/{property_id}" if property_id else ""
-
-        return f"{__base_url__}pages{object_id_}{properties_}{property_id_}"
+        return "%spages%s%s%s" % (
+            __base_url__,
+            f"/{object_id}" if object_id else "",
+            "/properties" if properties else "",
+            f"/{property_id}" if property_id else "",
+        )
 
     def _get(
         self,
@@ -130,26 +130,20 @@ class _NotionClient:
         /,
         *,
         payload: Optional[
-            Union[MutableMapping[str, Any], Union[Iterable[bytes], bytes, bytearray]]
+            Union[MutableMapping[str, Any], Union[bytes, Iterable[bytes]]]
         ] = None,
     ) -> MutableMapping[str, Any]:
-        if payload is None:
-            response = cast(
-                "MutableMapping[str, Any]",
-                default_json.loads(requests.get(url, headers=self.headers).text),
-            )
+        if not payload:
+            response = default_json.loads(requests.get(url, headers=self.headers).text)
         else:
             if isinstance(payload, dict):
                 payload = default_json.dumps(payload)
-            response = cast(
-                "MutableMapping[str, Any]",
-                default_json.loads(
-                    requests.post(url, headers=self.headers, json=payload).text
-                ),
+            response = default_json.loads(
+                requests.post(url, headers=self.headers, json=payload).text
             )
 
         validate_response(response)
-        return response
+        return cast(MutableMapping[str, Any], response)
 
     def _post(
         self,
@@ -157,53 +151,39 @@ class _NotionClient:
         /,
         *,
         payload: Optional[
-            Union[MutableMapping[str, Any], Union[Iterable[bytes], bytes, bytearray]]
+            Union[MutableMapping[str, Any], Union[bytes, Iterable[bytes]]]
         ] = None,
     ) -> MutableMapping[str, Any]:
-        if payload is None:
-            response = cast(
-                "MutableMapping[str, Any]",
-                default_json.loads(requests.post(url, headers=self.headers).text),
-            )
+        if not payload:
+            response = default_json.loads(requests.post(url, headers=self.headers).text)
         else:
             if isinstance(payload, dict):
                 payload = default_json.dumps(payload)
-            response = cast(
-                "MutableMapping[str, Any]",
-                default_json.loads(
-                    requests.post(url, headers=self.headers, data=payload).text
-                ),
+            response = default_json.loads(
+                requests.post(url, headers=self.headers, data=payload).text
             )
 
         validate_response(response)
-        return response
+        return cast(MutableMapping[str, Any], response)
 
     def _patch(
         self,
         url: str,
         /,
         *,
-        payload: Union[
-            MutableMapping[str, Any], Union[Iterable[bytes], bytes, bytearray]
-        ],
-    ) -> MutableMapping[str, Any]:  # -> MutableMapping[str, Any]:
+        payload: Union[MutableMapping[str, Any], Union[bytes, Iterable[bytes]]],
+    ) -> MutableMapping[str, Any]:
         if isinstance(payload, dict):
             payload = default_json.dumps(payload)
-        response = cast(
-            "MutableMapping[str, Any]",
-            default_json.loads(
-                requests.patch(url, headers=self.headers, data=payload).text
-            ),
+        response = default_json.loads(
+            requests.patch(url, headers=self.headers, data=payload).text
         )
 
         validate_response(response)
-        return response
+        return cast(MutableMapping[str, Any], response)
 
     def _delete(self, url: str, /) -> MutableMapping[str, Any]:
-        response = cast(
-            "MutableMapping[str, Any]",
-            default_json.loads(requests.delete(url, headers=self.headers).text),
-        )
+        response = default_json.loads(requests.delete(url, headers=self.headers).text)
 
         validate_response(response)
-        return response
+        return cast(MutableMapping[str, Any], response)
