@@ -44,8 +44,27 @@ from notion.exceptions.errors import (
     NotionObjectNotFound,
     NotionValidationError,
 )
-from notion.properties import *
 from notion.properties.build import build_payload
+from notion.properties.common import BotObject, Parent, UserObject, _NotionUUID
+from notion.properties.files import ExternalFile, FilesPropertyValue, InternalFile
+from notion.properties.propertyobjects import Option
+from notion.properties.propertyvalues import (
+    CheckboxPropertyValue,
+    DatePropertyValue,
+    EmailPropertyValue,
+    MultiSelectPropertyValue,
+    NumberPropertyValue,
+    PeoplePropertyValue,
+    PhoneNumberPropertyValue,
+    Properties,
+    RelationPropertyValue,
+    RichTextPropertyValue,
+    SelectPropertyValue,
+    StatusPropertyValue,
+    TitlePropertyValue,
+    URLPropertyValue,
+)
+from notion.properties.richtext import RichText
 
 if TYPE_CHECKING:
     from datetime import timedelta
@@ -89,12 +108,13 @@ class Page(_TokenBlockMixin):
         super().__init__(id, token=token, notion_version=notion_version)
         if token:
             self.token = token
+
         self.notion_version: Optional[str] = notion_version
         self.logger = _NLOG.getChild(f"{self.__repr__()}")
 
     @classmethod
     def create(
-        cls, parent_instance: Union[Page, Database, Block], /, *, page_title: str
+        cls, parent_instance: Union[Page, Database, Block], page_title: str
     ) -> Page:
         """
         Creates a blank page with properties.
@@ -103,7 +123,7 @@ class Page(_TokenBlockMixin):
 
         ---
         :param parent_instance: (required) an instance of\
-            `notion.api.notionpage.Page` or `notion.api.notiondatabase.Database`.
+                                `notion.api.notionpage.Page` or `notion.api.notiondatabase.Database`.
         :param page_title: (required)
         :param icon_url: (optional) #not yet implemented
         :param cover: (optional) #not yet implemented
@@ -124,14 +144,14 @@ class Page(_TokenBlockMixin):
         new_page = cls._post(parent_instance, cls._pages_endpoint(), payload=payload)
 
         cls_ = cls(new_page["id"])
-        cls_.logger.info(f"Page created in {parent_instance.__repr__()}")
-        cls_.logger.info(f"Url: {new_page['url']}")
-
+        cls_.logger.info(
+            f"Database created in {parent_instance.__repr__()}. Url: {new_page['url']}"
+        )
         return cls_
 
     def __getitem__(self, property_name: str) -> MutableMapping[str, Any]:
         try:
-            return self.properties[property_name]
+            return cast(MutableMapping[str, Any], self.properties[property_name])
         except KeyError:
             raise NotionObjectNotFound(
                 f"{property_name} not found in page property values."
@@ -143,7 +163,7 @@ class Page(_TokenBlockMixin):
 
     @cached_property
     def properties(self) -> MutableMapping[str, Any]:
-        return self._retrieve["properties"]
+        return cast(MutableMapping[str, Any], self._retrieve["properties"])
 
     @property
     def title(self) -> str:
@@ -169,37 +189,44 @@ class Page(_TokenBlockMixin):
 
     @property
     def url(self) -> MutableMapping[str, Any]:
-        return self._retrieve["url"]
+        return cast(MutableMapping[str, Any], self._retrieve["url"])
 
     @property
     def icon(self) -> MutableMapping[str, Any]:
-        return self._retrieve["icon"]
+        return cast(MutableMapping[str, Any], self._retrieve["icon"])
 
     @property
     def cover(self) -> MutableMapping[str, Any]:
-        return self._retrieve["cover"]
+        return cast(MutableMapping[str, Any], self._retrieve["cover"])
 
     @property
     def delete_self(self) -> None:
+        if self.is_archived:
+            self.logger.info("delete_self did nothing. Page is already archived.")
+            return None
+
         self._delete(self._block_endpoint(self.id))
         self.logger.info("Deleted self.")
 
     @property
     def restore_self(self) -> None:
+        if not self.is_archived:
+            self.logger.info("restore_self did nothing. Page is not archived.")
+            return None
+
         self._patch(self._pages_endpoint(self.id), payload=(b'{"archived": false}'))
         self.logger.info("Restored self.")
 
     def retrieve(
         self, *, filter_properties: Optional[list[str]] = None
     ) -> MutableMapping[str, Any]:
-        """
+        """ 
         Retrieves a Page object using the ID specified.
 
-        ---
         :param filter_properties: (optional) A list of page property value IDs associated with the page.\
-            Use this param to limit the response to a specific page property value or values.\
-            To retrieve multiple properties, specify each page property ID.\
-            E.g. ?filter_properties=iAk8&filter_properties=b7dh.
+                                   Use this param to limit the response to a specific page property value or values.\
+                                   To retrieve multiple properties, specify each page property ID.\
+                                   E.g. ?filter_properties=iAk8&filter_properties=b7dh.
 
         https://developers.notion.com/reference/retrieve-a-page
         """
@@ -209,8 +236,7 @@ class Page(_TokenBlockMixin):
                 name_id = self.properties[name]["id"]
                 _pages_endpoint_filtered_prop += f"filter_properties={name_id}&"
             return self._get(_pages_endpoint_filtered_prop)
-        else:
-            return self._get(self._pages_endpoint(self.id))
+        return self._get(self._pages_endpoint(self.id))
 
     def _retrieve_property_id(self, property_name: str) -> str:
         """Internal function to retrieve the id of a property.
@@ -219,8 +245,7 @@ class Page(_TokenBlockMixin):
         """
         if property_name in self.properties:
             return str(self.properties[property_name]["id"])
-        else:
-            raise NotionInvalidJson("Property name not found in parent schema.")
+        raise NotionInvalidJson("Property name not found in parent schema.")
 
     def retrieve_property_item(
         self,
@@ -234,9 +259,9 @@ class Page(_TokenBlockMixin):
 
         ---
         :param property_name: (required) property name in Notion *case-sensitive\
-            this endpoint only works with property_id's, internal function will retrieve this.
+                               this endpoint only works with property_id's, internal function will retrieve this.
         :param results_only: if true, returns the `results` key index[0] for paginated responses.\
-            will be either a single dictionary or a list of dictionaries.
+                             will be either a single dictionary or a list of dictionaries.
         :param property_item_only: if true, returns the `property_item` key.
 
         https://developers.notion.com/reference/retrieve-a-page-property
@@ -258,8 +283,7 @@ class Page(_TokenBlockMixin):
         """
         Updates page property values for the specified page.
         Properties not set via the properties parameter will remain unchanged.
-        If the parent is a database,
-        new property values must conform to the parent database's property schema.
+        If parent is a database, new property values must conform to the parent database's property schema.
 
         https://developers.notion.com/reference/patch-page
         """
@@ -275,6 +299,7 @@ class Page(_TokenBlockMixin):
         See block objects for more detail on determining if that block has nested children.
         In order to receive a complete representation of a block, you
         may need to recursively retrieve block children of child blocks.
+
         page_size Default: 100 page_size Maximum: 100.
 
         https://developers.notion.com/reference/get-block-children
@@ -299,14 +324,15 @@ class Page(_TokenBlockMixin):
     def set_select(self, column_name: str, select_option: str) -> None:
         """
         :param select_option: (required) if the option already exists, then it is\
-            case sensitive. if the option does not exist, it will be created.
+                               case sensitive. if the option does not exist, it will be created.
         """
-        available = Database(
+        current_options = Database(
             self.parent_id,
             token=self.token,
             notion_version=self.notion_version,
         )[column_name]["select"]["options"]
-        names = {n.get("name"): n.get("color") for n in available}
+
+        names = {n.get("name"): n.get("color") for n in current_options}
 
         if set([select_option]).issubset(names):
             option = Option(select_option, names.get(select_option))
@@ -318,17 +344,18 @@ class Page(_TokenBlockMixin):
     def set_multiselect(self, column_name: str, multi_select_options: list[str]) -> None:
         """
         :param multi_select_options: (required) list of strings for each select option.\
-            if the option already exists, then it is case sensitive.\
-            if the option does not exist, it will be created.
+                                      if the option already exists, then it is case sensitive.\
+                                      if the option does not exist, it will be created.
         """
         selected_options: list[Option] = []
 
-        available = Database(
+        current_options = Database(
             self.parent_id,
             token=self.token,
             notion_version=self.notion_version,
         )[column_name]["multi_select"]["options"]
-        names = {n.get("name"): n.get("color") for n in available}
+
+        names = {n.get("name"): n.get("color") for n in current_options}
 
         for option in multi_select_options:
             if set([option]).issubset(names):
@@ -343,16 +370,17 @@ class Page(_TokenBlockMixin):
     def set_status(self, column_name: str, status_option: str) -> None:
         """
         :param status_option: (required) unlike select/multi-select,\
-            status option must already exist when using this endpoint.\
-            to create a new status option, use the database endpoints.
+                               status option must already exist when using this endpoint.\
+                               to create a new status option, use the database endpoints.
         """
         try:
-            available = Database(
+            current_options = Database(
                 self.parent_id,
                 token=self.token,
                 notion_version=self.notion_version,
             )[column_name]["status"]["options"]
-            names = {n.get("name"): n.get("color") for n in available}
+
+            names = {n.get("name"): n.get("color") for n in current_options}
 
             if set([status_option]).issubset(names):
                 option = Option(status_option, names.get(status_option))
@@ -362,10 +390,7 @@ class Page(_TokenBlockMixin):
             self._patch_properties(Properties(StatusPropertyValue(column_name, option)))
         except NotionValidationError:
             self.logger.error(
-                "{} {}".format(
-                    NotionValidationError().__notes__[0],
-                    "Cannot create new status options via the API.",
-                )
+                f"{NotionValidationError().__notes__[0]}\nCannot create new status options via the API."
             )
 
     def set_date(
@@ -376,14 +401,14 @@ class Page(_TokenBlockMixin):
     ) -> None:
         """
         :param start: (required) A date, with an optional time.\
-            If the "date" value is a range, then start represents the start of the range.
+                       If the "date" value is a range, then start represents the start of the range.
         :param end: (optional) A string representing the end of a date range.\
-            If the value is null, then the date value is not a range.
+                     If the value is null, then the date value is not a range.
         """
         if isinstance(start, datetime):
-            start = start.replace().astimezone(self.tz)
+            start = start.astimezone(self.tz)
         if end and isinstance(end, datetime):
-            end = end.replace().astimezone(self.tz)
+            end = end.astimezone(self.tz)
 
         self._patch_properties(
             Properties(DatePropertyValue(column_name, start=start, end=end))
@@ -413,9 +438,9 @@ class Page(_TokenBlockMixin):
         """
         :param related_ids: (required) list of notion page ids to reference
         """
-        list_ids: list[NotionUUID] = []
+        list_ids: list[_NotionUUID] = []
         for id in related_ids:
-            list_ids.append(NotionUUID(id))
+            list_ids.append(_NotionUUID(id))
 
         self._patch_properties(Properties(RelationPropertyValue(column_name, list_ids)))
 
@@ -431,7 +456,7 @@ class Page(_TokenBlockMixin):
         """
         self._patch_properties(Properties(NumberPropertyValue(column_name, new_number)))
 
-    def set_people(self, column_name: str, user_array: list[UserObject]) -> None:
+    def set_people(self, column_name: str, user_array: Sequence[UserObject]) -> None:
         self._patch_properties(Properties(PeoplePropertyValue(column_name, user_array)))
 
     def set_email(self, column_name: str, email: str) -> None:
