@@ -54,7 +54,7 @@ from datetime import datetime
 from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from notion.properties.build import NotionObject
-from notion.properties.common import NotionUUID, UserObject
+from notion.properties.common import BotObject, UserObject, _NotionUUID
 from notion.properties.options import FunctionFormat
 from notion.properties.propertyobjects import Option, PropertyObject
 from notion.properties.richtext import Equation, Mention, RichText
@@ -150,11 +150,9 @@ class RichTextPropertyValue(PagePropertyValue, NotionObject):
         },
         ```
 
-        ---
-        :The RichText Object:
-        https://developers.notion.com/reference/rich-text
-        :The RichText Property Value:
-        https://developers.notion.com/reference/page-property-values#rich-text
+        The RichText Object: https://developers.notion.com/reference/rich-text
+
+        The RichText Property Value: https://developers.notion.com/reference/page-property-values#rich-text
         """
         super().__init__(property_name=property_name)
         self.set("type", "rich_text")
@@ -168,7 +166,6 @@ class TitlePropertyValue(PagePropertyValue, NotionObject):
         """
         :param title: (required) An array of rich text objects: `notion.properties.propertyvalues.RichText`
 
-        ---
         https://developers.notion.com/reference/page-property-values#title
         """
         super().__init__(property_name="title")
@@ -192,9 +189,9 @@ class DatePropertyValue(PagePropertyValue, NotionObject):
 
         ---
         :param start: (required) A date, with an optional time.\
-            If the "date" value is a range, then start represents the start of the range.
+                       If the "date" value is a range, then start represents the start of the range.
         :param end: (optional) A string representing the end of a date range.\
-            If the value is null, then the date value is not a range.
+                     If the value is null, then the date value is not a range.
 
         https://developers.notion.com/reference/page-property-values#date
         """
@@ -210,7 +207,7 @@ class RelationPropertyValue(PagePropertyValue, NotionObject):
     def __init__(
         self,
         property_name: str,
-        *related_ids: list[NotionUUID],
+        *related_ids: list[_NotionUUID],
         has_more: Optional[bool] = None,
     ) -> None:
         """
@@ -218,18 +215,18 @@ class RelationPropertyValue(PagePropertyValue, NotionObject):
 
         ---
         :param related_ids: (required) An array of related page references.\
-            A page reference is an object with an id key and a string value (UUIDv4)\
-            corresponding to a page ID in another database.
+                             A page reference is an object with an id key and a string value (UUIDv4)\
+                             corresponding to a page ID in another database.
 
         :param has_more: (optional) If a relation has more than 25 references, then the has_more value for\
-            the relation in the response object is true. If a relation doesn't\
-            exceed the limit, then has_more is false.
+                          the relation in the response object is true. If a relation doesn't\
+                          exceed the limit, then has_more is false.
 
         https://developers.notion.com/reference/page-property-values#relation
         """
         super().__init__(property_name=property_name)
         self.set("type", "relation")
-        self.set("relation", [x for x in related_ids][0])
+        self.set("relation", [id for id in related_ids][0])
         if has_more:
             self.set("has_more", True)
 
@@ -240,7 +237,7 @@ class StatusPropertyValue(PagePropertyValue, NotionObject):
     def __init__(self, property_name: str, status_option: Option, /) -> None:
         """
         :param status_option: (required) a single status option: `notion.properties.Option`\
-            containing `name` and `notion.properties.PropertyColor`
+                               containing `name` and `notion.properties.PropertyColor`
 
         https://developers.notion.com/reference/page-property-values#status
         """
@@ -256,11 +253,11 @@ class SelectPropertyValue(PagePropertyValue, NotionObject):
         """
         When selecting options, If the select database property does not yet have an option by the input name,
         then the name will be added to the database schema if the integration also has write access to the parent database.
-        NOTE: Commas (",") are not valid for select values.
-
+        
         ---
         :param select_option: (required) a single select option: `notion.properties.Option`\
-            containing `name` and `notion.properties.PropertyColor`
+                               containing `name` and `notion.properties.PropertyColor`\
+                               NOTE: Commas (",") are not valid for select values.
 
         https://developers.notion.com/reference/page-property-values#select
         """
@@ -277,11 +274,11 @@ class MultiSelectPropertyValue(PagePropertyValue, NotionObject):
         The MultiSelectPropertyValue contains an array of `notion.properties.Option` objects.
         When selecting options, If the multi-select database property does not yet have an option by the input name,
         then the name will be added to the database schema if the integration also has write access to the parent database.
-        NOTE: Commas (",") are not valid for select values.
 
         ---
         :param options_array: (required) array of `notion.properties.Option`\
-            containing `name` and `notion.properties.PropertyColor`
+                               containing `name` and `notion.properties.PropertyColor`\
+                               NOTE: Commas (",") are not valid for select values.
 
         https://developers.notion.com/reference/page-property-values#multi-select
         """
@@ -307,13 +304,13 @@ class CheckboxPropertyValue(PagePropertyValue, NotionObject):
 class PeoplePropertyValue(PagePropertyValue, NotionObject):
     __slots__: Sequence[str] = ["name"]
 
-    def __init__(self, property_name: str, user_array: list[UserObject], /) -> None:
+    def __init__(self, property_name: str, user_array: Sequence[UserObject], /) -> None:
         """
         :param user_array: (required) An array of user objects.\
-            The Retrieve a page endpoint can't be guaranteed to return more than 25 people\
-            per people page property. If a people page property includes more than 25 people,\
-            then you can use the Retrieve a page property item endpoint for the specific
-            people property to get a complete list of people.
+                            The Retrieve a page endpoint can't be guaranteed to return more than 25 people\
+                            per people page property. If a people page property includes more than 25 people,\
+                            then you can use the Retrieve a page property item endpoint for the specific
+                            people property to get a complete list of people.
 
         https://developers.notion.com/reference/page-property-values#people
         """
@@ -330,13 +327,14 @@ class RollupPropertyValue(PagePropertyValue, NotionObject):
         :param function: (required) `notion.properties.FunctionFormat`, function to update property to.
 
         ---
-        If the results of the rollup is a date (e.g. function = latest date), the results
-        will be a DatePropertyValue.
-        If the results of the rollup is a number (e.g. function = sum), the results will be
-        a NumberPropertyValue.
+        If the results of the rollup is a date (e.g. function = latest date),
+        the results will be a DatePropertyValue.
+
+        If the results of the rollup is a number (e.g. function = sum),
+        the results will be a NumberPropertyValue.
+
         If the results of the rollup is anything requireing multiple values (e.g. function = show original),
-        the results will be an array object, with a key 'type' = 'array',
-        and key 'array' containing a list of values.
+        the results will be an array object, with a key 'type' = 'array', and key 'array' containing a list of values.
 
         NOTE: Only the function key can be updated via the API.
 
