@@ -21,9 +21,7 @@
 # SOFTWARE.
 
 """ 
-Visit https://developers.notion.com/reference/post-database-query for info on database queries and filter/sort objects.
-
-`from notion import query`
+See https://developers.notion.com/reference/post-database-query for info on database queries and filter/sort objects.
 
 `notion.query.PropertyFilter` && `notion.query.TimestampFilter` for individual filters as used in Notion UI.
 
@@ -31,9 +29,12 @@ Visit https://developers.notion.com/reference/post-database-query for info on da
     :method: _and(): combine all filters in an `and` grouping.
     :method: _or(): combine all filters in an `or` grouping.
 
-    Create a separate CompoundFilter object to nest an `and` operator inside another `and` or `or`.
+    Create a separate CompoundFilter object to nest an `and`/`or` operator inside another `and`/`or`.
 
-`notion.query.SortFilter` contains a list of either *`notion.query.PropertyValueSort` | `notion.query.EntryTimestampSort`
+`notion.query.SortFilter` takes a list of either *`notion.query.PropertyValueSort` | `notion.query.EntryTimestampSort`
+
+To combine a CompoundFilter/PropertyFilter with a SortFilter,
+use `notion.build_payload(...)`
 """
 from typing import Sequence
 
